/* 
 * VirtualBox Control Service
 * 
 * Copyright © 2010 vu1tur.eu.org
 * 
 * This file is part of VirtualBox Control Service
 * 
 * VirtualBox Control Service is free software; you can redistribute it 
 * and/or modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 of 
 * the License, or (at your option) any later version.
 * 
 * VirtualBox Control Service is distributed in the hope that it will 
 * be useful, but WITHOUT ANY WARRANTY; without even the implied 
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

#ifndef _vboxctrltray_h
#define _vboxctrltray_h

#include <windows.h>
#include <stdlib.h>
#include <shellapi.h>
#include <time.h>
#include <stdio.h>
#include <process.h>
#include "res/resource.h"

#define UNUSED(x) (void)(x)

#define WM_APP						0x8000
#define WMAPP_NOTIFYCALLBACK		0x8001

#define VBCST_SUCCESS				0x00
#define VBCST_ERROR_NOCONF			0x01
#define VBCST_ERROR_MEMALLOC		0x02
#define VBCST_ERROR_INICORRUPTED	0x03
#define VBCST_ERROR_SVC_DENIED		0x04
#define VBCST_ERROR_SCM_DENIED		0x05


#define VMSTATUS_STOPPED				1
#define VMSTATUS_STOPPING				2
#define VMSTATUS_STARTING				3
#define VMSTATUS_RUNNING				4
#define VMSTATUS_SAVED					5
#define VMSTATUS_UNKNOWN				6 // Keep this one the last OK status
#define VMSTATUS_NOTFOUND				7
#define VMSTATUS_SVCERROR				8
#define VMSTATUS_MISSING				9
#define VMSTATUS_LAST					9

#define VMMENU_ROOT(x)		IDM_FIRSTVM + (x)*IDM_STEPVM
#define VMMENU_START(x)		VMMENU_ROOT(x) + IDM_STARTVM
#define VMMENU_STOP(x)		VMMENU_ROOT(x) + IDM_STOPVM
#define VMMENU_AUTO(x)		VMMENU_ROOT(x) + IDM_AUTOVM
#define VMMENU_SHOWLOG(x)	VMMENU_ROOT(x) + IDM_SHOWLOG
#define VMMENU_CONSOLE(x)	VMMENU_ROOT(x) + IDM_CONSOLE
#define VMMENU_POWEROFF(x)	VMMENU_ROOT(x) + IDM_POWEROFF
#define VMMENU_ACPIPOWER(x)	VMMENU_ROOT(x) + IDM_ACPIPOWER
#define VMMENU_ACPISLEEP(x) VMMENU_ROOT(x) + IDM_ACPISLEEP
#define VMMENU_SAVESTATE(x)	VMMENU_ROOT(x) + IDM_SAVESTATE
#define VMMENU_OPENINI(x)	VMMENU_ROOT(x) + IDM_OPENINI
#define VMMENU_CLEARLOG(x) 	VMMENU_ROOT(x) + IDM_CLEARLOG

typedef struct {
	int status;
	char name[128];
	char configFile[MAX_PATH];
	char logFile[MAX_PATH];
	char displayName[256];
	char serviceName[256];
	int shutdownCommand;
	LONG vrdpPort;
	BOOL autostart;
} VBoxMachineInfo;

HBITMAP IconToBitmap(HICON hicon);
INT_PTR CALLBACK DlgProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
BOOL CreateNotoficationIcon(HWND hwnd);
void ShowContextMenu(HWND hwnd);
void CreateContextMenu(int lastError);
int ReadConfig();
int UpdateServices();
int UpdateServices(bool fromIPC);
void CloseTrayHelper();
void ToggleAutostart();
BOOL IsAutostarted();
HICON GetStatusIcon(int status);
DWORD CheckForUpdates(BOOL silent);

#endif